@@ -414,6 +414,19 @@ def XYZwrite(src, filename):
     fh.close()
 
 
+def XSCwrite(mol, filename, frames=None):
+    if frames is None and mol.numFrames != 0:
+        frames = mol.frame
+    else:
+        frames = 0
+    box = mol.box[:, frames]
+    step = mol.step[frames]
+    with open(filename, 'w') as f:
+        f.write('# NAMD extended system configuration restart file generated by MoleculeKit\n')
+        f.write('#$LABELS step a_x a_y a_z b_x b_y b_z c_x c_y c_z o_x o_y o_z\n')
+        f.write(f"{step} {box[0]:e} {0:e} {0:e} {0:e} {box[1]:e} {0:e} {0:e} {0:e} {box[2]:e} {0:e} {0:e} {0:e} {0:e} {0:e} {0:e} {0:e} {0:e} {0:e}")
+
+
 def MOL2write(mol, filename):
     uqresname = np.unique(mol.resname)
     if len(uqresname) > 1:
@@ -590,7 +603,8 @@ _WRITERS = {'psf': PSFwrite,
             'xyz': XYZwrite,
             'gro': GROwrite,
             'coor': BINCOORwrite,
-            'xtc': XTCwrite}
+            'xtc': XTCwrite,
+            'xsc': XSCwrite}
 
 
 for ext in _MDTRAJ_SAVERS:
